"""
Tests for conveyor.conveyor module
"""
import argparse
from unittest.mock import patch, MagicMock

import conveyor.conveyor as con

expected_settings = {
    "qa_delivery_area": "/lustre/aoc/cluster/pipeline/docker/workspaces/qa2",
    "weblog_cache_area": "/lustre/aoc/cluster/pipeline/docker/workspaces/cache/weblog",
    "workspaces_lustre_root_dir": "/lustre/aoc/cluster/pipeline/docker/workspaces/spool",
    "current_root_directory": "current/directory",
    "current_subdirectory": "dir_123",
    "destination_dir": "/lustre/aoc/cluster/pipeline/docker/workspaces/spool/tmpabcd1234",
    "destination_subdir": "tmpabcd1234",
}
args = argparse.Namespace()


class TestConveyor:
    def test_get_settings(self):
        with patch("pathlib.Path.cwd") as cwd:
            settings = con._get_settings("test/test.json")
            assert settings["qa_delivery_area"] == expected_settings["qa_delivery_area"]
            assert settings["weblog_cache_area"] == expected_settings["weblog_cache_area"]
            assert (
                settings["workspaces_lustre_root_dir"]
                == expected_settings["workspaces_lustre_root_dir"]
            )
            # mock calls to cwd and count
            assert cwd.call_count == 2
            assert settings["destination_dir"] == expected_settings["destination_dir"]
            assert settings["destination_subdir"] == expected_settings["destination_subdir"]

    def test_main_deliver(self):
        args.deliver = ["test/test.json"]

        with patch("argparse.ArgumentParser.parse_args", MagicMock(return_value=args)) as mock_args:
            assert args.deliver[0] == "test/test.json"
            with patch("conveyor.deliver.DeliveryConveyor.convey") as del_convey:
                con.main()
                assert del_convey.call_count == 1

        # reset for other testing
        args.deliver = None

    def test_main_retrieve(self):
        args.retrieve = ["test/test.json"]

        with patch("argparse.ArgumentParser.parse_args", MagicMock(return_value=args)) as mock_args:
            with patch("conveyor.retrieve.RetrievalConveyor.convey") as ret_convey:
                con.main()
                assert ret_convey.call_count == 1

        # reset for other testing
        args.retrieve = None
